====================================
Docstrings for basic field functions
====================================

Field operation functions
=========================

These functions implement some basic operations pertaining to fields
in general.

.. autofunction:: sympy.physics.vector.fieldfunctions.curl

.. autofunction:: sympy.physics.vector.fieldfunctions.divergence

.. autofunction:: sympy.physics.vector.fieldfunctions.gradient

.. autofunction:: sympy.physics.vector.fieldfunctions.scalar_potential

.. autofunction:: sympy.physics.vector.fieldfunctions.scalar_potential_difference


Checking the type of vector field
=================================

.. autofunction:: sympy.physics.vector.fieldfunctions.is_conservative

.. autofunction:: sympy.physics.vector.fieldfunctions.is_solenoidal
